@@ -4,6 +4,15 @@ package Wx::Demo;
 
 Wx::Demo - the wxPerl demo
 
+=head1 AUTHOR
+
+Mattia Barbon <mbarbon@cpan.org>
+
+=head1 LICENSE
+
+This program is free software; you can redistribute it and/or
+modify it under the same terms as Perl itself.
+
 =cut
 
 use Wx;
@@ -29,10 +38,11 @@ sub new {
       ( undef, -1, 'wxPerl demo', wxDefaultPosition, [ 600, 500 ],
         wxDEFAULT_FRAME_STYLE|wxNO_FULL_REPAINT_ON_RESIZE|wxCLIP_CHILDREN );
 
+    # $self->SetLayoutDirection( Wx::wxLayout_RightToLeft() );
     Wx::InitAllImageHandlers();
 
     # create menu bar
-      my $bar = Wx::MenuBar->new;
+    my $bar = Wx::MenuBar->new;
     my $file = Wx::Menu->new;
     $file->Append( wxID_EXIT, "E&xit" );
 
@@ -224,6 +234,11 @@ sub populate_modules {
         foreach my $tag ( $module->add_to_tags ) {
             my $parent_id = $tag_map{$tag};
 
+            unless( $parent_id ) {
+                Wx::LogWarning( 'Wrong parent: %s', $tag );
+                next;
+            }
+
             add_item( $tree, $parent_id, $module );
         }
     }
@@ -276,7 +291,7 @@ package Wx::Demo::Source;
 use strict;
 
 use Wx qw(:stc :textctrl :font wxDefaultPosition wxDefaultSize
-          wxNO_FULL_REPAINT_ON_RESIZE);
+          wxNO_FULL_REPAINT_ON_RESIZE wxLayout_LeftToRight);
 
 our @ISA = ( eval 'require Wx::STC' ) ? 'Wx::StyledTextCtrl' : 'Wx::TextCtrl';
 
@@ -343,6 +358,9 @@ sub new {
         $self->SetLexer( wxSTC_LEX_PERL );
     }
 
+    $self->SetLayoutDirection( wxLayout_LeftToRight )
+      if $self->can( 'SetLayoutDirection' );
+
     return $self;
 }
 
